[日本語版 README ](/README-ja.md)

# H-RISK with NoiseModelling

## About

This is a QGIS plugin, which implements NoiseModelling (https://github.com/Universite-Gustave-Eiffel/NoiseModelling) and help estimate the health risks posed by (road traffic) noise.
The author has also made an application to estimate the risk posed by noise from wind turbines. See https://gitlab.com/jtagusari/hrisk-wtn.

![](tutorial/result.png)

Figure: Sound levels along a road in Sapporo city (see the Tutorial).



## Features

This plugin can

- Fetch geometries from OpenStreetMap, Shuttle Radar Topography Mission, and Vector Tiles (provided by the Geospatial Information Authority of Japan).
- Predict sound levels by executing NoiseModelling, by executing the Java script (specified Java implementation is required).
- Estimate health risks based on the predicted sound levels and expore-response relationships shown in the Environmental Noise Guidelines in European Region (WHO Regional Office for Europe).

The scripts of NoiseModelling are not translated: this plugin executes them using shell command and you can replace it with a newer version.
NoiseModelling v4.0.4 is supported since H-RISK v0.1.0.
NoiseModelling v4.0.4 is supported since H-RISK v0.1.4.

## License

This plug-in complies with the GPL v3 license. 
Please see the LICENSE file for details.

License of the external program used by this plug-in:

- NoiseModelling: GPL v3
- OpenJDK: GPL v2 (Classpath Exception)

Note: This service uses the API function of the e-Stat, Japan, but the content of the service is not guaranteed by the government of Japan.

## How to install

### QGIS

Install QGIS.
The version later than than 3.22.0 is required.

### This plugin

From the menu "Management and Install of Plugins" on QGIS, find this plugin "H-RISK with NoiseModelling" and install it.
Note that most functionalities including predicting sound levels are not available unless you install NoiseModelling in the next step.

Or, you can also install this plugin using a zip file.
Download all of this project from the repository (<https://gitlab.com/jtagusari/hrisk-noisemodelling>) and install it on QGIS.

### NoiseModelling and Java environment

*Note: an executable installer was removed after version 0.1.6 because it may be identified as malware.*

#### Automated install on QGIS

Execute `Install required components` algorithm in this plugin.
NoiseModelling and Java environment are installed in your computer, and environmental variables of `NOISEMODELLING_HOME` and `JAVA_FOR_NOISEMODELLING` are set.

If there were problems, try manual installation shown in the next part.


#### Manual install of NoiseModelling

1. Download No-GUI version of NoiseModelling (see <https://github.com/Universite-Gustave-Eiffel/NoiseModelling/releases>)
2. Save all the files in your PC (e.g. `C:\Program Files\NoiseModelling\4.0.5`)
3. Set environmental variable of `NOISEMODELLING_HOME` to the folder where `bin` folder is located (e.g. `C:\Program Files\NoiseModelling\4.0.5\scriptrunner`). Note that `%NOISEMODELLING_HOME%\bin\wps_scripts` exists.

#### Java environment

1. Check the requirements of NoiseModelling and obtain the required version of Java implementation
2. Save all the files in your PC (e.g. `C:\Program Files\Java`)
3. Set environmental variable of `JAVA_FOR_NOISEMODELLING` to the installed folder. Note that `%JAVA_FOR_NOISEMODELLING%\bin\java.exe` exists.



## Tutorial

Here is a tutorial of this plugin.
Execute the following procedures on QGIS, where the sound levels and health risks in 1km2 area in Sapporo City Suburb (141.295,141.305,43.158,43.168 [EPSG:4326]) are estimated step-by-step.
The results are also stored in `tutorial` directory of this repository.

For testing algorithms, use `testalgorithms` algorithm (see the next section) instead of executing this tutorial.

### Fetch the geometries

With following procedures, roads, buildings, elevation points, and a raster containing population information are fetched.
If the parameters are unspecified, use the default values.

- Execute `Road centerline (OSM)` algorithm (in `Fetch geometries` group) using following parameters. Note that `QuickOSM` plugin is needed before the execution.
  - `FETCH_EXTENT`: 141.295,141.305,43.158,43.168 [EPSG:4326]
  - `TARGET_CRS`: EPSG: 32654
  - `BUFFER`: 500.0 (m)
- Execute `Building (OSM)` algorithm using following parameters:
  - `FETCH_EXTENT`: 141.295,141.305,43.158,43.168 [EPSG:4326]
  - `TARGET_CRS`: EPSG: 32654
  - `BUFFER`: 500.0
- Execute `Elevation points (SRTM)` algorithm using following parameters. Note that user id and password of Earthdata Login (https://urs.earthdata.nasa.gov/users/new) is needed before the execution.
  - `FETCH_EXTENT`: 141.295,141.305,43.158,43.168 [EPSG:4326]
  - `TARGET_CRS`: EPSG: 32654
  - `BUFFER`: 500.0
  - `USERNAME`: (registered user name)
  - `PASSWORD`: (registered password)
- Execute `Population (Ja)` algorithm (in `Fetch geometries (Ja)` group) using following parameters. Note that only the population in Japan can be fetched using this algorithm.
  - `FETCH_EXTENT`: 141.295,141.305,43.158,43.168 [EPSG:4326]
  - `TARGET_CRS`: EPSG: 32654
  - `BUFFER`: 500.0


If you want to obtain the information on roads and buildings and set them as sound sources and obstacles without this plugin, following procedures are needed (quite complex!). 

1. Get the fetch extent as a rectangle
   1. Execute `native:extenttolayer` using the above `FETCH_EXTENT` as `INPUT` 
   2. Execute `native:reprojectlayer` using the output of the previous procedure as `INPUT` and the above `TARGET_CRS` as `TARGET_CRS`
   3. Execute `native:buffer` using the output of the previous procedure as `INPUT` and the above `BUFFER` as `DISTANCE`
2. Get the features from OpenStreetMap
   1. Execute `quickosm:downloadosmdataextentquery` using highway as `KEY` (if for buildings, building as `KEY`) and the extent of the obtained rectangle as the `EXTENT`
   2. Execute `native:reprojectlayer` using the output of the previous procedure as `INPUT` and the above `TARGET_CRS` as `TARGET_CRS`
   3. Execute `native:dissolve` using the output of the previous procedure as `INPUT` and the all the fields as `FIELD`
   4. Execute `native:multiparttosingleparts` using the output of the previous procedure as `INPUT`
3. Set required fields
   1. Add required fields to the road layer (`PK`,`LV_d`, `LV_e`, `LV_n`, `MV_d`, `MV_e`, `MV_n`, `HV_d`, `HV_e`, `HV_n`, `LV_spd_d`, `LV_spd_e`, `LV_spd_n`, `MV_spd_d`, `MV_spd_e`, `MV_spd_n`, `HV_spd_d`, `HV_spd_e`, `HV_spd_n`, `LWd63`, `LWd125`, `LWd250`, `LWd500`, `LWd1000`, `LWd2000`, `LWd4000`, `LWd8000`, `LWe63`, `LWe125`, `LWe250`, `LWe500`, `LWe1000`, `LWe2000`, `LWe4000`, `LWe8000`, `LWn63`, `LWn125`, `LWn250`, `LWn500`, `LWn1000`, `LWn2000`, `LWn4000`, `LWn8000`, `pvmt`, `temp_d`, `temp_e`, `temp_n`, `ts_stud`, `pm_stud`, `junc_dist`, `slope`, `way`)
   2. Add required fields to the building layer (`PK`,`height`)

### Set traffic volume

As an example, set following traffic volumes, for roads of which `osm_id` are `202548600` and `1128470753`

- `LV_d`: 1000
- `LV_e`: 400
- `LV_n`: 120
- `HV_d`: 140
- `HV_e`: 20
- `HV_n`: 20

### Set populations

This step is for estimating health risks.

- Execute `Estimate populations of buildings using Raster` algorithm in `Evaluate health risk` group using following parameters.
  - `BUILDING`: (buildings fetched in the previous procedure)
  - `POPULATION`: (population fetched in the previous procedure)

### Set receivers (at building facade)

- Execute `Building facade` algorithm in `Set receiver` group using following parameters. Receiver points in front of the buildings are created using algorithms implemented in `NoiseModelling`. Note that `NoiseModelling` and `Java` are needed before the execution (see "How to install" section)
  - `BUILDING`: (buildings fetched in the previous procedure)
  - `SOURCE`: (roads fetched in the previous procedure)
  - `FENCE_EXTENT`: 141.295,141.305,43.158,43.168 [EPSG:4326]
  - `DELTA`: 2.0
  - `DISTANCE`: 0.01

The receivers at buildings facade are used to estimate health risks posed by noise exposure.

### Set receivers (at delaunay grid)

- Execute `Delaunay grid` algorithm in `Set receiver` group using following parameters.
  - `BUILDING`: (buildings fetched in the previous procedure)
  - `SOURCE`: (roads fetched in the previous procedure)
  - `FENCE_EXTENT`: 141.295,141.305,43.158,43.168 [EPSG:4326]
  - `MAX_AREA`: 100.0

The receivers at delaunay grid points are used to create sound-level contours.
The delaunay triangular polygons, which is one of the outputs of the procedure, are also needed for creating sound-level contour.

### Calculate the sound levels

- Execute `Prediction from traffic` algorithm in `Predict sound level` group using following parameters. The sound levels are computed using algorithms implemented in `NoiseModelling`.
  - `ROAD`: (roads fetched in the previous procedure)
  - `BUILDING`: (buildings fetched in the previous procedure)
  - `RECEIVER`: (receiver points created in the previous procedure)
  - `DEM`: (elevation points fetched in the previous procedure)
  - `MAX_SRC_DIST`: 500

As 2 types of the receivers (at Delaunay triangulation and at buildings facade), 2 calculations can be carried out and 2 results are obtained.
Note that sound-levels assigned buildings are also created when the receivers at building facade are applied.

### Create sound-level contour (delaunay-grid receivers)

The sound-level result of the receivers at Delaunay triangulation is used to create sound-level contour.

- Execute `Isosurface` algorithm in `Predict sound level` group using following parameters. The sound-level counters are computed using algorithms implemented in `NoiseModelling`. As an example, Lden contour is created.
  - `LEVEL_RESULT`: (Lden computed in the previous procedure, using delaunay grid)
  - `LEVEL_RID`: IDRECEIVER
  - `LEVEL_LID`: LAEQ
  - `TRIANGLES`: (delaunay triangles obtained in the previous procedure)


### Estimate health risks (building-facade receivers)

The health risks for each building are already estimated. See the attribute table of the buildings.

Even after calculating the sound levels, the health risks can be estimated by the following steps:

- Assign the population to the buildings by `Estimate populations of buildings using Raster` algorithm
- Assign the sound levels to the buildings by `Assign calculated levels to buildings` algorithm (Lden and Lnight are required)
- Estimate the health risks by `Estimate health risks of buildings` algorithm


Note that when the sound levels are assigned to each building, reflection effects (approx 3 dB) were cancelled by subtracting this value.

### Complete

The tutorial is finished.
Noise maps displaying day, evening and night sound levels were obtained, and moreover, health risks were estimated.

## Test algorithms

Successful operation of the algorithms is verified by `testalgorithms` algortihm, in the `Configurations` group.
Several test cases encompassing the implemented algorithms are prepared and the outputs of the algorithms are confirmed through these cases.

For example, the `Set receivers` case is for veryfying algorithms in the `Set receivers` group. Receivers at buildings facade, delaunay triangulation grids, regular grids and a crosssection are computed using respective algorithms and check the hash values of the results, which were prepared by the author.

When the outputs pass the test, messages such as `Hash check PASSED` are displayed.
`Hash check FAILED` indicates that the hash value is different from the prepared value.

However, it should be noted that algorithms for fetching geometries may throw such message even though they are working fine. Since these algorithms fetch data from remote servers, the outputs may not be an exact match (e.g. the order of the geometries may be different).
It is important to confirm that all algorithms except for fetching algorithms pass the tests.

## Implemented algorithms

### Fetch geometries

The user can fetch geometries of roads and buildings using algorithms in `Fetch geometries` group.
In Japan, precised data (including population) can be obtained using algorithms in `Fetch geometries (Ja)` group.

Implemented algorithms are:

- `Fetch geometries` group
  - Road centerline (OSM) (`fetchroadosm.py`): fetch road geometries from OpenStreetMap. `QuickOSM` is needed.
  - Building (OSM) (`fetchbuildingosm.py`): fetch building geometries from OpenStreetMap. `QuickOSM` is needed.
  - Elevation points (SRTM) (`fetchdemrastersrtm.py`): fetch elevation-points geometries from Shuttle Radar Topography Mission dataset. User id and password of Earthdata Login (https://urs.earthdata.nasa.gov/users/new) is needed.
  - Population (GHS) (`fetchpop`): fetch 100m-mesh population from Global Human Settlement dataset (https://ghsl.jrc.ec.europa.eu/). 
- `Fetch geometries (Ja)` group
  - Road centerline (Ja) (`fetchroadja.py`): fetch road geometries from vector-tile map provided by the GSI of Japan
  - Buildings (Ja) (`fetchbuildingja.py`): fetch building geometries from vector-tile map provided by the GSI of Japan
  - Elevation points (Ja) (`fetchdemvectorja.py`/`fetchdemrasterja`): fetch elevation-points geometries from (vector-)tile map provided by the GSI of Japan
  - Population (Ja) (`fetchpopja.py`): fetch 250m-mesh population from the ESTAT-API of Japan
  - Fetch geometries (Ja) (`fetchallja.py`): fetch all geometries listed above (and also set receivers, if specified)

Note that `QuickOSM` plugin (https://docs.3liz.org/QuickOSM/) is needed to fetch geometries from OpenStreetMap.
To fetch geometries from Shuttle Radar Topography Mission, user id and password of Earthdata Login (https://urs.earthdata.nasa.gov/users/new) is needed.

### Initialize geometries

The following algorithms that initialize geometries (set required fields) are in `Initialize features` group.

Algorithms in `Initialize features` group are:

- Road with acoustic information (`initroad.py`): initialize linestrings as roads
- Arbitrary sound source with acoustic information (`initsource.py`): initialize points as sound sources
- Road emission calculated from traffic (`initroademissionfromtraffic.py`): calculate the emission level (sound power level) using the traffic volume
- Building (`initbuilding.py`): initialize polygons as buildings
- Elevation point (`initelevationpoint.py`): initialize points as elevation points
- Elevation point (`heightsalonglines.py`): initialize points using line geometries (points along the lines)
- Ground absorption (`initgroundabsorption.py`): initialize polygons as ground absorption
- Receivers (`initreceiver.py`): initialize points as receivers

### Merge geometries

- Merge roads (`mergeroad.py`): merge multiple road geometries
- Merge buildings (`mergebuildings.py`): merge multiple building geometries
- Merge elevation points (`mergeelevationpoints.py`): merge multiple elevation points geometries


### Set receiver points

To set receiver points, algorithms in `Set receivers` group are available.
They execute `NoiseModelling` algorithms and set receiver points such as at building facades and at delaunay grid points.


Algorithms in `Set receiver` group are:

- At building facade (`receiverfacade.py`): create receivers at building facades
- Delaunay grid (`receiverdelaunaygrid.py`): create receivers at delaunay grid points and triangles
- Regular grid (`receiverregulargrid.py`): create receivers at regular grid points
- On cross section line (`receivercrosssection.py`): create receivers at cross section lines, with different heights

### Calculate sound levels

Sound levels at the receiver points can be calculate using algorithms in `Predict sound level` group, which employ `NoiseModelling`.

Algorithms in `Predict sound level` group are:

- Prediction from traffic (`noisefromtraffic.py`): calculate the sound levels from traffic volume
- Prediction from emission (`noisefromemission.py`): calculate the sound levels from the sound power level
- Isosurface (`isosurface.py`): create isosurface lines from the calculated sound levels and delaunay triangles

### Estimate health risks

The user can assign the number of residents of each building and estimate health risks posed by the noise, using algorithms in `Evaluate health risk` group.

Algorithms in `Evaluate health risk` group are:

- Estimate populations of buildings using Raster (`estimatepopulationofbuilding.py`): estimate the number of residents for each building using a raster representing the population
- Estimate populations of buildings using Polygon (`estimatepopulationofbuildingplg.py`): estimate the number of residents for each building using polygons representing the population
- Assign calculated levels to buildings (`estimatelevelofbuilding.py`): estimate the sound level for each building
- Estimate health risks of buildings (`estimateriskofbuilding.py`): estimate the health risks for each building


## How to uninstall

Delete the files and folders in `JAVA_FOR_NOISEMODELLING` and `NOISEMODELLING_HOME` paths and delete the environmental variables.
