from qgis.PyQt.QtCore import QT_TRANSLATE_NOOP

from qgis.core import (
  QgsProcessing,
  QgsProcessingParameterFeatureSource,
  QgsProcessingParameterDistance,
  QgsProcessingParameterNumber,
  QgsProcessingParameterFeatureSink,
  QgsFeatureRequest
  )

from qgis import processing


from ..algabstract import algabstract

class heightsalonglines(algabstract):
  

  PARAMETERS = {            
    "INPUT": {
      "crs_referrence": True, # this parameter is used as CRS referrence
      "ui_func": QgsProcessingParameterFeatureSource,
      "ui_args":{
        "description": QT_TRANSLATE_NOOP("heightsalonglines","Input layer"),
        "types": [QgsProcessing.TypeVectorLine]
      }
    },
    "INTERVAL": {
      "ui_func": QgsProcessingParameterDistance,
      "ui_args": {
        "description": QT_TRANSLATE_NOOP("heightsalonglines","Interval between points"),
        "defaultValue": 10.0,
        "parentParameterName": "INPUT"
      }
    },
    "HEIGHT": {
      "ui_func": QgsProcessingParameterNumber,
      "ui_args": {
        "description": QT_TRANSLATE_NOOP("heightsalonglines","Height (m)"),
        "type": QgsProcessingParameterNumber.Double,
        "minValue": -100.0, "defaultValue": 0.0, "maxValue": 10000.0
      }
    },
    "OUTPUT": {
      "ui_func": QgsProcessingParameterFeatureSink,
      "ui_args": {
        "description": QT_TRANSLATE_NOOP("heightsalonglines","Elevation points" )
      },
      "visibleByDefault": False
    }
  }
  
  def initAlgorithm(self, config):
    self.initParameters()
    
  def processAlgorithm(self, parameters, context, feedback):  
    point_xy = processing.run(
      "native:pointsalonglines",
      {
        "INPUT": self.parameterAsSource(parameters, "INPUT", context).materialize(QgsFeatureRequest(), feedback),
        "INTERVAL": self.parameterAsDouble(parameters, "INTERVAL", context),
        "OUTPUT": "TEMPORARY_OUTPUT"
      }
    )["OUTPUT"]
    
    point_xyz = processing.run(
      "native:setzvalue",
      {
        "INPUT": point_xy,
        "Z_VALUE": self.parameterAsDouble(parameters, "HEIGHT", context),
        "OUTPUT": "TEMPORARY_OUTPUT"
      }
    )["OUTPUT"]
        
    point_elev = processing.run(
      "hrisk:initelevationpoint",
      {
          "INPUT": point_xyz,
          "TARGET_CRS": self.parameterAsCrs(parameters, "INPUT", context),
          "OVERWRITE": True,
          "OUTPUT": "TEMPORARY_OUTPUT"
      }
    )["OUTPUT"]
    
    (sink, dest_id) = self.parameterAsSink(
      parameters, "OUTPUT", context, point_elev.fields(), point_elev.wkbType(), point_elev.sourceCrs()
      )
    
    for ft in point_elev.getFeatures():
      sink.addFeature(ft)
      
    return {"OUTPUT": dest_id}
  
  
  def createInstance(self):
    return heightsalonglines()


  def displayName(self):
    return self.tr("Elevation points along lines")

  def group(self):
    return self.tr("Initialize features")

  def groupId(self):
    return "initfeature"

  def createInstance(self):
    return heightsalonglines()
