from qgis.PyQt.QtCore import (
  QT_TRANSLATE_NOOP, QVariant
  )
from qgis.core import (
  QgsProcessing,
  QgsProcessingParameterFeatureSource,
  QgsProcessingParameterFeatureSink,
  QgsProcessingParameterBoolean,
  QgsFeatureRequest,
  QgsProcessingParameterCrs,
  QgsVectorLayer
  )

from .initabstract import initabstract

from qgis import processing

class initsource(initabstract):
  PARAMETERS = {                  
    "INPUT": {
      "ui_func": QgsProcessingParameterFeatureSource,
      "ui_args":{
        "description": QT_TRANSLATE_NOOP("initsource","Source layer"),
        "types": [QgsProcessing.TypeVectorLine, QgsProcessing.TypeVectorPoint],
        "optional": True
      }
    },
    "USE_ZVALUE": {
      "ui_func": QgsProcessingParameterBoolean,
      "ui_args":{
        "description" : QT_TRANSLATE_NOOP("initsource","Use z values of the geometry?"),
        "defaultValue": False
      }
    },
    "TARGET_CRS": {
      "ui_func": QgsProcessingParameterCrs,
      "ui_args": {
        "description": QT_TRANSLATE_NOOP("initsource","Target CRS (Cartesian coordinates)")
      }
    },
    "OVERWRITE": {
      "ui_func": QgsProcessingParameterBoolean,
      "ui_args":{
        "description" : QT_TRANSLATE_NOOP("initsource","Overwrite existing fields?"),
        "defaultValue": True
      }
    },
    "OUTPUT": {
      "ui_func": QgsProcessingParameterFeatureSink,
      "ui_args": {
        "description": QT_TRANSLATE_NOOP("initsource","Source" )
      }
    }
  }
  
  def __init__(self):
    super().__init__()
    self.FIELDS_REQUIRED.update(
      {    
        "LWd63":      {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 63 Hz (dB) (6-18h)
        "LWd125":     {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 125 Hz (dB) (6-18h)
        "LWd250":     {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 250 Hz (dB) (6-18h)
        "LWd500":     {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 500 Hz (dB) (6-18h)
        "LWd1000":    {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 1000 Hz (dB) (6-18h)
        "LWd2000":    {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 2000 Hz (dB) (6-18h)
        "LWd4000":    {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 4000 Hz (dB) (6-18h)
        "LWd8000":    {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 8000 Hz (dB) (6-18h)
        "LWe63":      {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 63 Hz (dB) (18-22h)
        "LWe125":     {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 125 Hz (dB) (18-22h)
        "LWe250":     {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 250 Hz (dB) (18-22h)
        "LWe500":     {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 500 Hz (dB) (18-22h)
        "LWe1000":    {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 1000 Hz (dB) (18-22h)
        "LWe2000":    {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 2000 Hz (dB) (18-22h)
        "LWe4000":    {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 4000 Hz (dB) (18-22h)
        "LWe8000":    {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 8000 Hz (dB) (18-22h)
        "LWn63":      {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 63 Hz (dB) (22-6h)
        "LWn125":     {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 125 Hz (dB) (22-6h)
        "LWn250":     {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 250 Hz (dB) (22-6h)
        "LWn500":     {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 500 Hz (dB) (22-6h)
        "LWn1000":    {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 1000 Hz (dB) (22-6h)
        "LWn2000":    {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 2000 Hz (dB) (22-6h)
        "LWn4000":    {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 4000 Hz (dB) (22-6h)
        "LWn8000":    {"TYPE": QVariant.Double, "DEFAULT_VALUE": None}, # Octave-band sound power level at 8000 Hz (dB) (22-6h)  
      }
    )
  
  def initAlgorithm(self, config):
    (rect, target_crs) = self.getExtentAndCrsUsingCanvas()
    self.PARAMETERS["TARGET_CRS"]["ui_args"]["defaultValue"] = target_crs.authid()

    self.initParameters()
    
  def processAlgorithm(self, parameters, context, feedback):
    target_crs = self.parameterAsCrs(parameters, "TARGET_CRS", context)
    # check whether the target CRS is x-y coordinates
    self.checkCrsAsCartesian(target_crs, feedback)

    try:
      self.INPUT_LAYER = processing.run(
        "native:reprojectlayer", 
        {
          "INPUT": self.parameterAsSource(parameters, "INPUT", context).materialize(QgsFeatureRequest(), feedback),
          "TARGET_CRS": target_crs,
          "OUTPUT": "TEMPORARY_OUTPUT"
        }
      )["OUTPUT"]      
            
    except:
      self.INPUT_LAYER = QgsVectorLayer(f"Point?crs={target_crs.authid()}", "temp", "memory")
    
    if self.parameterAsBoolean(parameters, "USE_ZVALUE", context):
      test_geom = self.INPUT_LAYER.getFeatures().__next__().geometry()
      if test_geom.get().nCoordinates() != 3:
        feedback.reportError(self.tr("The input layer has no Z values."))
        raise Exception(self.tr("The input layer has no Z values."))
    else:
      self.INPUT_LAYER = processing.run(
        "native:setzvalue",
        {
          "INPUT": self.INPUT_LAYER,
          "Z_VALUE": 0.05,
          "OUTPUT": "TEMPORARY_OUTPUT"
        }
      )["OUTPUT"]
      
    self.setFieldsDict(
      parameters, context, feedback, 
      self.INPUT_LAYER.fields(), 
      self.parameterAsBoolean(parameters, "OVERWRITE", context)
    )
    
    # define the feature sink
    (sink, dest_id) = self.parameterAsSink(
      parameters, "OUTPUT", context, 
      self.FIELDS_INIT, 
      self.INPUT_LAYER.wkbType(), 
      self.INPUT_LAYER.sourceCrs()
    )
    
    self.resetPk()    
    self.addFeaturesToSink(sink, dest_id, self.INPUT_LAYER)
              
    return {"OUTPUT": dest_id}
  
  def createInstance(self):
    return initsource()


  def displayName(self):
    return self.tr("Sound source")

  def group(self):
    return self.tr("Initialize features")

  def groupId(self):
    return "initfeature"

  def createInstance(self):
    return initsource()
